import { JSONArrayOf, JSONValue } from '../../json';
export interface JSONRPCRequestOptions {
    func: string;
    params: any;
    timeout?: number;
    token?: string;
}
export interface JSONRPCRequest {
    method: string;
    version: '1.1';
    id: string;
    params: Array<JSONValue>;
    context?: any;
}
export interface JSONRPCErrorInfo {
    code: string;
    status?: number;
    message: string;
    detail?: string;
    data?: any;
}
export interface JSONRPCClientParams {
    url: string;
    timeout: number;
    token?: string;
}
export interface JSONPayload {
    version: string;
    method: string;
    id: string;
    params: Array<JSONValue>;
}
export interface JSONRPC11Error {
    name: string;
    code: number;
    message: string;
    error: JSONValue;
}
export type JSONRPCError = JSONRPC11Error;
export declare class JSONRPC11Exception extends Error {
    error: JSONRPC11Error;
    constructor(error: JSONRPCError);
}
export interface JSONRPCResponseResult {
    result: Array<JSONValue>;
    error: null;
}
export interface JSONRPCResponseError {
    result: null;
    error: JSONRPCError;
}
export type JSONRPCResponse = JSONRPCResponseResult | JSONRPCResponseError;
export declare class JSONRPCClient {
    url: string;
    timeout: number;
    token?: string;
    constructor({ url, timeout, token }: JSONRPCClientParams);
    protected makePayload(method: string, params: Array<JSONValue>): JSONPayload;
    callMethod(method: string, params: Array<JSONValue>, { timeout }?: {
        timeout?: number;
    }): Promise<JSONArrayOf<JSONValue>>;
}
