"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JSONRPCClient = exports.JSONRPC11Exception = void 0;
const uuid_1 = require("uuid");
class JSONRPC11Exception extends Error {
    constructor(error) {
        super(error.message);
        this.error = error;
    }
}
exports.JSONRPC11Exception = JSONRPC11Exception;
class JSONRPCClient {
    constructor({ url, timeout, token }) {
        this.url = url;
        this.timeout = timeout;
        this.token = token;
    }
    makePayload(method, params) {
        return {
            version: '1.1',
            method,
            id: (0, uuid_1.v4)(),
            params
        };
    }
    callMethod(method, params, { timeout } = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = this.makePayload(method, params);
            const headers = new Headers();
            headers.set('content-type', 'application/json');
            headers.set('accept', 'application/json');
            if (this.token) {
                headers.set('authorization', this.token);
            }
            const response = yield fetch(this.url, {
                method: 'POST',
                body: JSON.stringify(payload),
                headers
            });
            const result = yield (() => __awaiter(this, void 0, void 0, function* () {
                const responseText = yield response.text();
                try {
                    return JSON.parse(responseText);
                }
                catch (ex) {
                    console.error('error', ex);
                    throw new JSONRPC11Exception({
                        name: 'parse error',
                        code: 100,
                        message: 'The response from the service could not be parsed',
                        error: {
                            originalMessage: ex.message,
                            responseText
                        }
                    });
                }
            }))();
            if (result.hasOwnProperty('error')) {
                const errorResult = result;
                throw new JSONRPC11Exception({
                    name: errorResult.error.name,
                    code: errorResult.error.code,
                    message: errorResult.error.message,
                    error: errorResult.error.error
                });
            }
            const rpcResponse = result;
            return rpcResponse.result;
        });
    }
}
exports.JSONRPCClient = JSONRPCClient;
//# sourceMappingURL=JSONRPC11.js.map